==> alg-example-1.38.14-20200918.114356-1-sources.jar: cn/com/duiba/nezha/alg/example/util/StdCoderModelSaveBo.java <==
package cn.com.duiba.nezha.alg.example.util;

import cn.com.duiba.nezha.alg.common.util.StringZIP;
import cn.com.duiba.nezha.alg.model.CODER;
import cn.com.duiba.nezha.alg.example.util.conf.JedisPoolConf;
//import cn.com.duiba.nezha.compute.biz.conf.MongoDbConf;
import cn.com.duiba.nezha.alg.example.constant.ProjectConstant;
//import cn.com.duiba.nezha.compute.biz.dto.DenseCoderDo;
//import cn.com.duiba.nezha.compute.biz.utils.mongodb.MongoClientUtil;
import cn.com.duiba.nezha.alg.common.util.AssertUtil;


import cn.com.duiba.nezha.alg.model.CODER2;
import com.alibaba.fastjson.JSON;

public class StdCoderModelSaveBo {


//    public static MongoClientUtil mongoClientUtil = new MongoClientUtil(MongoDbConf.config);

    public static JedisUtil jedisUtil = new JedisUtil(JedisPoolConf.jedisConfig);

    public static JedisUtil actJedisUtil = new JedisUtil(JedisPoolConf.actJedisConfig);

    public static JedisUtil dpaActJedisUtil = new JedisUtil(JedisPoolConf.dpaActJedisConfig);


    /**
     * @param modelKey
     * @return
     */
    private static String getLastModelKey(String modelKey) {

        return "nz_last_model_new_" + modelKey + "_";
    }

    /**
     * @param modelKey
     * @return
     */
    private static String getADXModelKey(String modelKey) {

        return "TAE:ALGBID:MODEL:" + modelKey;
    }

//    /**
//     * @param modelKey
//     * @param denseCoderDo
//     * @return
//     */
//    public static void saveFieldCoderByKeyToJedis(String modelKey, DenseCoderDo denseCoderDo) {
//
//        if (cn.com.duiba.nezha.alg.common.util.AssertUtil.isAnyEmpty(modelKey, denseCoderDo)) {
//            System.out.println("saveModelByKeyToJedis,modelKey=" + modelKey);
//            return;
//        }
//        try {
//            // 获取缓存Key
//            String key = getLastModelKey(modelKey);
//            // 保存
//            System.out.println("save model with key " + key);
//            String value = JSON.toJSONString(denseCoderDo);
//            String value2 = StringZIP.zipString(value); //压缩
//
//            jedisUtil.setex(key, value2, ProjectConstant.WEEK_1_EXPIRE);
//
//        } catch (Exception e) {
//            e.printStackTrace();
//        }
//    }
//
//
//    /**
//     * @param modelKey
//     * @return
//     */
//    public static DenseCoderDo getFieldCoderByKeyFromJedis(String modelKey) {
//        DenseCoderDo ret = null;
//
//        if (AssertUtil.isAnyEmpty(modelKey)) {
//            System.out.println("getModelByKeyFromJedis empty,modelKey=" + modelKey);
//            return ret;
//        }
//        try {
//            // 获取缓存Key
//            String key = getLastModelKey(modelKey);
//            System.out.println("read model with key=" + key);
//            // 保存
//            String ret1 = jedisUtil.get(key);
//            String ret2 = StringZIP.unzipString(ret1);// 解压
//            // 解压
//            ret = JSON.parseObject(ret2, DenseCoderDo.class);
//
//        } catch (Exception e) {
//            e.printStackTrace();
//        }
//
//        return ret;
//    }


    /**
     * @param modelKey
     * @param CODER
     * @return
     */
    public static void saveModelCoderByKeyToJedis(String modelKey, CODER CODER, String redis) {

        if (cn.com.duiba.nezha.alg.common.util.AssertUtil.isAnyEmpty(modelKey, CODER)) {
            System.out.println("saveModelByKeyToJedis,modelKey=" + modelKey);
            return;
        }
        try {
            // 获取缓存Key
            String key = getLastModelKey(modelKey);
            // 保存
            System.out.println("save model with key " + key);
            String value = JSON.toJSONString(CODER);
            String value2 = StringZIP.zipString(value); //压缩


            if (redis == "act") {
                actJedisUtil.setex(key, value2, ProjectConstant.WEEK_1_EXPIRE);
            } else {
                jedisUtil.setex(key, value2, ProjectConstant.WEEK_1_EXPIRE);
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * @param modelKey
     * @param CODER
     * @return
     */
    public static void saveModelCoderByKeyToJedis(String modelKey, CODER CODER, JedisUtil redis) {

        if (cn.com.duiba.nezha.alg.common.util.AssertUtil.isAnyEmpty(modelKey, CODER)) {
            System.out.println("saveModelByKeyToJedis,modelKey=" + modelKey);
            return;
        }
        try {
            // 获取缓存Key
            String key = getLastModelKey(modelKey);
            // 保存
            System.out.println("save model with key " + key);
            String value = JSON.toJSONString(CODER);
            String value2 = StringZIP.zipString(value); //压缩

            redis.setex(key, value2, ProjectConstant.YEAR_1_EXPIRE);

        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    /**
     * @param modelKey
     * @param CODER
     * @return
     */
    public static void saveModelCoderByKeyToJedis(String modelKey, CODER CODER) {

        if (cn.com.duiba.nezha.alg.common.util.AssertUtil.isAnyEmpty(modelKey, CODER)) {
            System.out.println("saveModelByKeyToJedis,modelKey=" + modelKey);
            return;
        }
        try {
            // 获取缓存Key
            String key = getLastModelKey(modelKey);
            // 保存
            System.out.println("save model with key " + key);
            String value = JSON.toJSONString(CODER);
            String value2 = StringZIP.zipString(value); //压缩

            jedisUtil.setex(key, value2, ProjectConstant.WEEK_1_EXPIRE);

        } catch (Exception e) {
            e.printStackTrace();
        }
    }
    /**
     * @param modelKey
     * @param CODER
     * @return
     */
    public static void saveADXModelCoderByKeyToJedis(String modelKey, CODER CODER) {

        if (cn.com.duiba.nezha.alg.common.util.AssertUtil.isAnyEmpty(modelKey, CODER)) {
            System.out.println("saveModelByKeyToJedis,modelKey=" + modelKey);
            return;
        }
        try {
            // 获取缓存Key
            String key = getADXModelKey(modelKey);
            // 保存
            System.out.println("save model with key " + key);
            String value = JSON.toJSONString(CODER);
            String value2 = StringZIP.zipString(value); //压缩

            jedisUtil.setex(key, value2, ProjectConstant.WEEK_1_EXPIRE);

        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    /**
     * @param modelKey
     * @return
     */
    public static CODER getModelCoderByKeyFromJedis(String modelKey) {
        CODER ret = null;

        if (AssertUtil.isAnyEmpty(modelKey)) {
            System.out.println("getModelByKeyFromJedis empty,modelKey=" + modelKey);
            return ret;
        }
        try {
            // 获取缓存Key
            String key = getLastModelKey(modelKey);
            System.out.println("read model with key=" + key);
            // 保存
            String ret1 = jedisUtil.get(key);
            String ret2 = StringZIP.unzipString(ret1);// 解压
            // 解压
            ret = JSON.parseObject(ret2, CODER.class);

        } catch (Exception e) {
            e.printStackTrace();
        }

        return ret;
    }

    /**
     * @param modelKey
     * @return
     */
    public static CODER2 getModelCoder2ByKeyFromJedis(String modelKey) {
        CODER2 ret = null;

        if (AssertUtil.isAnyEmpty(modelKey)) {
            System.out.println("getModelByKeyFromJedis empty,modelKey=" + modelKey);
            return ret;
        }
        try {
            // 获取缓存Key
            String key = getLastModelKey(modelKey);
            System.out.println("read model with key=" + key);
            // 保存
            String ret1 = jedisUtil.get(key);
            String ret2 = StringZIP.unzipString(ret1);// 解压
            // 解压
            ret = JSON.parseObject(ret2, CODER2.class);

        } catch (Exception e) {
            e.printStackTrace();
        }

        return ret;
    }

    /**
     * @param modelKey
     * @return
     */
    public static CODER getADXModelCoderByKeyFromJedis(String modelKey) {
        CODER ret = null;

        if (AssertUtil.isAnyEmpty(modelKey)) {
            System.out.println("getModelByKeyFromJedis empty,modelKey=" + modelKey);
            return ret;
        }
        try {
            // 获取缓存Key
            String key = getADXModelKey(modelKey);
            System.out.println("read model with key=" + key);
            // 保存
            String ret1 = jedisUtil.get(key);
            String ret2 = StringZIP.unzipString(ret1);// 解压
            // 解压
            ret = JSON.parseObject(ret2, CODER.class);

        } catch (Exception e) {
            e.printStackTrace();
        }

        return ret;
    }


    /**
     * @param modelKey
     * @return
     */
    public static CODER getModelCoderByKeyFromJedis(String modelKey, String redis) {
        CODER ret = null;

        if (AssertUtil.isAnyEmpty(modelKey)) {
            System.out.println("getModelByKeyFromJedis empty,modelKey=" + modelKey);
            return ret;
        }
        try {
            // 获取缓存Key
            String key = getLastModelKey(modelKey);
            System.out.println("read model with key=" + key);
            // 保存


            String ret1 = null;

            if (redis == "act") {
                ret1 = actJedisUtil.get(key);
            } else if(redis == "dpa") {
                ret1 = dpaActJedisUtil.get(key);
            } else {
                ret1 = jedisUtil.get(key);
            }

            String ret2 = StringZIP.unzipString(ret1);// 解压
            // 解压
            ret = JSON.parseObject(ret2, CODER.class);

        } catch (Exception e) {
            e.printStackTrace();
        }

        return ret;
    }


    /**
     * @param modelKey
     * @return
     */
    public static CODER getModelCoderByKeyFromJedis(String modelKey, JedisUtil redis) {
        CODER ret = null;

        if (AssertUtil.isAnyEmpty(modelKey)) {
            System.out.println("getModelByKeyFromJedis empty,modelKey=" + modelKey);
            return ret;
        }
        try {
            // 获取缓存Key
            String key = getLastModelKey(modelKey);
            System.out.println("read model with key=" + key);
            // 保存


            String ret1 = null;

            ret1 = redis.get(key);

            String ret2 = StringZIP.unzipString(ret1);// 解压
            // 解压
            ret = JSON.parseObject(ret2, CODER.class);

        } catch (Exception e) {
            e.printStackTrace();
        }

        return ret;
    }

    /**
     * @param modelKey
     * @return
     */
    public static CODER2 getModelCoder2ByKeyFromJedis(String modelKey, JedisUtil redis) {
        CODER2 ret = null;

        if (AssertUtil.isAnyEmpty(modelKey)) {
            System.out.println("getModelByKeyFromJedis empty,modelKey=" + modelKey);
            return ret;
        }
        try {
            // 获取缓存Key
            String key = getLastModelKey(modelKey);
            System.out.println("read model with key=" + key);
            // 保存


            String ret1 = null;

            ret1 = redis.get(key);

            String ret2 = StringZIP.unzipString(ret1);// 解压
            // 解压
            ret = JSON.parseObject(ret2, CODER2.class);

        } catch (Exception e) {
            e.printStackTrace();
        }

        return ret;
    }

    /**
     * @param modelKey
     * @return
     */
    public static CODER getADXModelCoderByKeyFromJedis(String modelKey, JedisUtil redis) {
        CODER ret = null;

        if (AssertUtil.isAnyEmpty(modelKey)) {
            System.out.println("getModelByKeyFromJedis empty,modelKey=" + modelKey);
            return ret;
        }
        try {
            // 获取缓存Key
            String key = getADXModelKey(modelKey);
            System.out.println("read model with key=" + key);
            // 保存


            String ret1 = null;

            ret1 = redis.get(key);

            String ret2 = StringZIP.unzipString(ret1);// 解压
            // 解压
            ret = JSON.parseObject(ret2, CODER.class);

        } catch (Exception e) {
            e.printStackTrace();
        }

        return ret;
    }

    /**
     * @param modelKey
     * @return
     */
    public static CODER2 getADXModelCoder2ByKeyFromJedis(String modelKey, JedisUtil redis) {
        CODER2 ret = null;

        if (AssertUtil.isAnyEmpty(modelKey)) {
            System.out.println("getModelByKeyFromJedis empty,modelKey=" + modelKey);
            return ret;
        }
        try {
            // 获取缓存Key
            String key = getADXModelKey(modelKey);
            System.out.println("read model with key=" + key);
            // 保存


            String ret1 = null;

            ret1 = redis.get(key);

            String ret2 = StringZIP.unzipString(ret1);// 解压
            // 解压
            ret = JSON.parseObject(ret2, CODER2.class);

        } catch (Exception e) {
            e.printStackTrace();
        }

        return ret;
    }

}

==> alg-example-2.2.7-20190624.040346-1-sources.jar: cn/com/duiba/nezha/alg/example/util/StdCoderModelSaveBo.java <==
package cn.com.duiba.nezha.alg.example.util;

import cn.com.duiba.nezha.alg.common.util.StringZIP;
import cn.com.duiba.nezha.alg.model.Coder;
import cn.com.duiba.nezha.alg.example.util.conf.JedisPoolConf;
//import cn.com.duiba.nezha.compute.biz.conf.MongoDbConf;
import cn.com.duiba.nezha.alg.example.constant.ProjectConstant;
//import cn.com.duiba.nezha.compute.biz.dto.DenseCoderDo;
//import cn.com.duiba.nezha.compute.biz.utils.mongodb.MongoClientUtil;
import cn.com.duiba.nezha.alg.common.util.AssertUtil;




import com.alibaba.fastjson.JSON;

public class StdCoderModelSaveBo {


//    public static MongoClientUtil mongoClientUtil = new MongoClientUtil(MongoDbConf.config);

    public static JedisUtil jedisUtil = new JedisUtil(JedisPoolConf.jedisConfig);


    /**
     * @param modelKey
     * @return
     */
    private static String getLastModelKey(String modelKey) {

        return "nz_last_model_new_" + modelKey + "_";
    }


//    /**
//     * @param modelKey
//     * @param denseCoderDo
//     * @return
//     */
//    public static void saveFieldCoderByKeyToJedis(String modelKey, DenseCoderDo denseCoderDo) {
//
//        if (cn.com.duiba.nezha.alg.common.util.AssertUtil.isAnyEmpty(modelKey, denseCoderDo)) {
//            System.out.println("saveModelByKeyToJedis,modelKey=" + modelKey);
//            return;
//        }
//        try {
//            // 获取缓存Key
//            String key = getLastModelKey(modelKey);
//            // 保存
//            System.out.println("save model with key " + key);
//            String value = JSON.toJSONString(denseCoderDo);
//            String value2 = StringZIP.zipString(value); //压缩
//
//            jedisUtil.setex(key, value2, ProjectConstant.WEEK_1_EXPIRE);
//
//        } catch (Exception e) {
//            e.printStackTrace();
//        }
//    }
//
//
//    /**
//     * @param modelKey
//     * @return
//     */
//    public static DenseCoderDo getFieldCoderByKeyFromJedis(String modelKey) {
//        DenseCoderDo ret = null;
//
//        if (AssertUtil.isAnyEmpty(modelKey)) {
//            System.out.println("getModelByKeyFromJedis empty,modelKey=" + modelKey);
//            return ret;
//        }
//        try {
//            // 获取缓存Key
//            String key = getLastModelKey(modelKey);
//            System.out.println("read model with key=" + key);
//            // 保存
//            String ret1 = jedisUtil.get(key);
//            String ret2 = StringZIP.unzipString(ret1);// 解压
//            // 解压
//            ret = JSON.parseObject(ret2, DenseCoderDo.class);
//
//        } catch (Exception e) {
//            e.printStackTrace();
//        }
//
//        return ret;
//    }


    /**
     * @param modelKey
     * @param coder
     * @return
     */
    public static void saveModelCoderByKeyToJedis(String modelKey, Coder coder) {

        if (cn.com.duiba.nezha.alg.common.util.AssertUtil.isAnyEmpty(modelKey, coder)) {
            System.out.println("saveModelByKeyToJedis,modelKey=" + modelKey);
            return;
        }
        try {
            // 获取缓存Key
            String key = getLastModelKey(modelKey);
            // 保存
            System.out.println("save model with key " + key);
            String value = JSON.toJSONString(coder);
            String value2 = StringZIP.zipString(value); //压缩

            jedisUtil.setex(key, value2, ProjectConstant.WEEK_1_EXPIRE);

        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    /**
     * @param modelKey
     * @return
     */
    public static Coder getModelCoderByKeyFromJedis(String modelKey) {
        Coder ret = null;

        if (AssertUtil.isAnyEmpty(modelKey)) {
            System.out.println("getModelByKeyFromJedis empty,modelKey=" + modelKey);
            return ret;
        }
        try {
            // 获取缓存Key
            String key = getLastModelKey(modelKey);
            System.out.println("read model with key=" + key);
            // 保存
            String ret1 = jedisUtil.get(key);
            String ret2 = StringZIP.unzipString(ret1);// 解压
            // 解压
            ret = JSON.parseObject(ret2, Coder.class);

        } catch (Exception e) {
            e.printStackTrace();
        }

        return ret;
    }

}
